@@ -1,27 +1,25 @@
+# copyright 2002-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-constraint.
+#
+# logilab-constraint is free software: you can redistribute it and/or modify it
+# under the terms of the GNU Lesser General Public License as published by the
+# Free Software Foundation, either version 2.1 of the License, or (at your
+# option) any later version.
+#
+# logilab-constraint is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
+# for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-constraint. If not, see <http://www.gnu.org/licenses/>.
 """Unit testing for constraint propagation module"""
 
-# (c) 2005 LOGILAB S.A. (Paris, FRANCE).
-# http://www.logilab.fr/ -- mailto:contact@logilab.fr
-#
-# This program is free software; you can redistribute it and/or modify it under
-# the terms of the GNU General Public License as published by the Free Software
-# Foundation; either version 2 of the License, or (at your option) any later
-# version.
-#
-# This program is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License along with
-# this program; if not, write to the Free Software Foundation, Inc.,
-# 59 Temple Place - Suite 330, Boston, MA  02111-1307
-# USA.
-
-__revision__ = '$Id: test_fi.py,v 1.10 2005/08/04 13:08:53 adim Exp $'
-
 import unittest
 from logilab.constraint.fi import *
-
+from logilab.constraint import Repository, Solver
 
 class FiniteIntervalTC(unittest.TestCase):
 
@@ -467,8 +465,8 @@ class DistributorTC(unittest.TestCase):
         self.assertEquals(d1.size(), dom1['v1'].size() + dom2['v1'].size())
 
     def test_DistributeSameLengths(self):
-        d1 = FiniteIntervalDomain(0, 5, 3)
-        d2 = FiniteIntervalDomain(0, 20, 1)
+        d1 = FiniteIntervalDomain(lowestMin=0, highestMax=5,  min_length=4)
+        d2 = FiniteIntervalDomain(lowestMin=0, highestMax=20, min_length=1)
         domains = {'v1': d1,
                    'v2': d2,
                    }
@@ -483,6 +481,70 @@ class DistributorTC(unittest.TestCase):
         self.assertEquals(d1.size(), dom1['v1'].size() + dom2['v1'].size())
         
 
-    
+class PlannerTC(unittest.TestCase):
+    def setUp(self):
+        self.d = FiniteIntervalDistributor()
+        self.verbose = 1
+        
+    def solve_repo1(self, constraints):
+        dom1 = FiniteIntervalDomain(0, 15, 5)
+        dom2 = FiniteIntervalDomain(0, 15, 5)
+        dom3 = FiniteIntervalDomain(0, 15, 5)
+        repo = Repository( ['A','B','C'], { 'A': dom1,
+                                            'B': dom2,
+                                            'C': dom3 },
+                           constraints )
+        s = Solver( self.d )
+        answers = list(s.solve_all(repo,verbose=self.verbose))
+        self.assertEquals(len(answers), 2)
+        import pprint
+        pprint.pprint( list(answers) )
+
+    def test_pb1(self):
+        constraints = [ StartsAfterEnd('B','A'),
+                        StartsAfterEnd('C','A'),
+                        NoOverlap('B','C' ) ]
+        self.solve_repo1( constraints )
+
+    def test_pb2(self):
+        constraints = [ EndsBeforeStart('A','B'),
+                        EndsBeforeStart('A','C'),
+                        NoOverlap('B','C' ) ]
+        self.solve_repo1( constraints )
+
+
+    def solve_repo2(self, constraints):
+        dom1 = FiniteIntervalDomain(0, 20, 5)
+        dom2 = FiniteIntervalDomain(0, 20, 5)
+        dom3 = FiniteIntervalDomain(0, 20, 10)
+        dom4 = FiniteIntervalDomain(0, 20, 5)
+        repo = Repository( ['A','B','C', 'D'], { 'A': dom1,
+                                                 'B': dom2,
+                                                 'C': dom3,
+                                                 'D': dom4 },
+                           constraints )
+        s = Solver( self.d )
+        answers = list(s.solve_all(repo,verbose=1))
+        import pprint
+        pprint.pprint( list(answers) )
+
+    def test_pb3(self):
+        constraints = [ StartsAfterEnd('B','A'),
+                        StartsAfterEnd('C','A'),
+                        StartsAfterEnd('D','B'),
+                        StartsAfterEnd('D','C'),
+                        ]
+        self.solve_repo2( constraints )
+
+    def test_pb4(self):
+        constraints = [ StartsAfterEnd('B','A'),
+                        StartsAfterEnd('C','A'),
+                        StartsAfterEnd('D','B'),
+                        StartsAfterEnd('D','C'),
+                        StartsAfterEnd('D','A'),
+                        ]
+        self.solve_repo2( constraints )
+
+
 if __name__ == '__main__':
     unittest.main()
